@@ -47,11 +47,11 @@
 #include "nut_stdint.h"
 
 /* Prototypes to allow setting pointer before function is defined */
-int setcmd(const char* varname, const char* setvalue);
+int setvar(const char* varname, const char* setvalue);
 int instcmd(const char *cmdname, const char *extra);
 
 #define DRIVER_NAME	"Oneac EG/ON/OZ/OB UPS driver"
-#define DRIVER_VERSION	"0.86"
+#define DRIVER_VERSION	"0.87"
 
 /* driver description structure */
 upsdrv_info_t upsdrv_info = {
@@ -200,11 +200,6 @@ void upsdrv_initups(void)
 {
 	upsfd = ser_open(device_path);
 	ser_set_speed(upsfd, device_path, B9600);
-
-	/*get the UPS in the right frame of mind*/
-	ser_send_pace(upsfd, 100, "%s", COMMAND_END);
-	ser_send_pace(upsfd, 100, "%s", COMMAND_END);
-	sleep (1);
 }
 
 void upsdrv_initinfo(void)
@@ -215,6 +210,11 @@ void upsdrv_initinfo(void)
 	ssize_t RetValue;
 	char buffer[256], buffer2[32];
 
+	/* Get the UPS in the right frame of mind */
+	ser_send_pace(upsfd, 100, "%s", COMMAND_END);
+	ser_send_pace(upsfd, 100, "%s", COMMAND_END);
+	sleep (1);
+
 	/* All families should reply to this request so we can confirm that it is
 	 *  an ONEAC UPS
 	 */
@@ -252,7 +252,7 @@ void upsdrv_initinfo(void)
 	dstate_addcmd("shutdown.stop");
 	dstate_addcmd("shutdown.reboot");
 
-	upsh.setvar = setcmd;
+	upsh.setvar = setvar;
 	upsh.instcmd = instcmd;
 
 	/* set some stuff that shouldn't change after initialization */
@@ -967,7 +967,7 @@ int instcmd(const char *cmdname, const char *extra)
 }
 
 
-int setcmd(const char* varname, const char* setvalue)
+int setvar(const char* varname, const char* setvalue)
 {
 	upsdebug_SET_STARTING(varname, setvalue);
 
