@@ -38,7 +38,7 @@
 #include "timehead.h"
 
 #define DRIVER_NAME	"Microsol Rhino UPS driver"
-#define DRIVER_VERSION	"0.56"
+#define DRIVER_VERSION	"0.57"
 
 /* driver description structure */
 upsdrv_info_t upsdrv_info = {
@@ -785,6 +785,11 @@ void upsdrv_help(void)
 {
 }
 
+/* optionally tweak prognames[] entries */
+void upsdrv_tweak_prognames(void)
+{
+}
+
 void upsdrv_makevartable(void)
 {
 	addvar(VAR_VALUE, "battext", "Battery Extension (0-80)min");
