@@ -14,7 +14,7 @@
 # WARNING: Current working directory when starting the script should be
 # the location where it may create temporary data (e.g. the BUILDDIR).
 # Caller can export envvars to impact the script behavior, e.g.:
-#	DEBUG=true	to print debug messages, running processes, etc.
+#	DEBUG_NIT=true	to print debug messages, running processes, etc.
 #	DEBUG_SLEEP=60	to sleep after tests, with driver+server running
 #	NUT_DEBUG_MIN=3	to set (minimum) debug level for drivers, upsd...
 #	NUT_DEBUG_LEVEL_UPSSCHED=3	to set debug level for particular
@@ -109,7 +109,7 @@ log_separator() {
 }
 
 shouldDebug() {
-    [ -n "$DEBUG" ] || [ -n "$DEBUG_SLEEP" ]
+    [ -n "$DEBUG" ] || [ -n "$DEBUG_NIT" ] || [ -n "$DEBUG_SLEEP" ]
 }
 
 log_debug() {
@@ -1505,28 +1505,59 @@ testcase_sandbox_upsc_query_timer() {
     #rm -f "${NUT_STATEPATH}/upslog-dummy.log" || true
 }
 
+PY_SHEBANG=""
+PY_RES=127
 isTestablePython() {
     # We optionally make python module (if interpreter is found):
+    case x"${PY_SHEBANG}" in
+        x"") ;; # Fall through to detection
+        *) return $PY_RES ;; # Probably resolved (if not a comment)?
+    esac
+
     if [ x"${TOP_BUILDDIR}" = x ] \
     || [ ! -x "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py" ] \
     ; then
         return 1
     fi
-    PY_SHEBANG="`head -1 "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"`"
-    if [ x"${PY_SHEBANG}" = x"#!no" ] ; then
-        return 1
+
+    if [ x"${PYTHON}" != x ] ; then
+        PY_SHEBANG="#!${PYTHON}"
+        PY_RES=0
+        return 0
     fi
-    log_debug "=======\nDetected python shebang: '${PY_SHEBANG}'"
-    return 0
+
+    if [ x"${PYTHON_DEFAULT}" != x ] ; then
+        PYTHON="${PYTHON_DEFAULT}"
+        PY_SHEBANG="#!${PYTHON_DEFAULT}"
+        PY_RES=0
+        return 0
+    fi
+
+    PY_SHEBANG="`head -1 "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"`"
+    PY_RES=3
+    case x"${PY_SHEBANG}" in
+        x"#!"/*|x"#!"?":\\"*|x"#!"?":/"*) PY_RES=0 ;; # Seems like a full path
+        x"#!no")   PY_RES=1 ;; # Explicitly skipped
+        x"#!@")    PY_RES=2 ;; # Unresolved
+        *)         PY_RES=3 ;; # Unexpected twist
+    esac
+    if [ x"${PY_RES}" = x0 ] ; then
+        log_debug "=======\nDetected python shebang: '${PY_SHEBANG}' (result=${PY_RES})"
+        PYTHON="`echo "${PY_SHEBANG}" | sed 's,^#!,,'`"
+    else
+        log_error "[isTestablePython] Detected python shebang: '${PY_SHEBANG}' (result=${PY_RES})"
+    fi
+    return $PY_RES
 }
 
 testcase_sandbox_python_without_credentials() {
-    isTestablePython || return 0
+    isTestablePython && [ -n "${PYTHON}" ] || return 0
+
     log_separator
     log_info "[testcase_sandbox_python_without_credentials] Call Python module test suite: PyNUT (NUT Python bindings) without login credentials"
     if ( unset NUT_USER || true
          unset NUT_PASS || true
-        "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"
+        $PYTHON "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"
     ) ; then
         log_info "[testcase_sandbox_python_without_credentials] PASSED: PyNUT did not complain"
         PASSED="`expr $PASSED + 1`"
@@ -1538,7 +1569,7 @@ testcase_sandbox_python_without_credentials() {
 }
 
 testcase_sandbox_python_with_credentials() {
-    isTestablePython || return 0
+    isTestablePython && [ -n "${PYTHON}" ] || return 0
 
     # That script says it expects data/evolution500.seq (as the UPS1 dummy)
     # but the dummy data does not currently let issue the commands and
@@ -1549,7 +1580,7 @@ testcase_sandbox_python_with_credentials() {
         NUT_USER='admin'
         NUT_PASS="${TESTPASS_ADMIN}"
         export NUT_USER NUT_PASS
-        "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"
+        $PYTHON "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"
     ) ; then
         log_info "[testcase_sandbox_python_with_credentials] PASSED: PyNUT did not complain"
         PASSED="`expr $PASSED + 1`"
@@ -1561,7 +1592,7 @@ testcase_sandbox_python_with_credentials() {
 }
 
 testcase_sandbox_python_with_upsmon_credentials() {
-    isTestablePython || return 0
+    isTestablePython && [ -n "${PYTHON}" ] || return 0
 
     log_separator
     log_info "[testcase_sandbox_python_with_upsmon_credentials] Call Python module test suite: PyNUT (NUT Python bindings) with upsmon role login credentials"
@@ -1569,7 +1600,7 @@ testcase_sandbox_python_with_upsmon_credentials() {
         NUT_USER='dummy-admin'
         NUT_PASS="${TESTPASS_UPSMON_PRIMARY}"
         export NUT_USER NUT_PASS
-        "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"
+        $PYTHON "${TOP_BUILDDIR}/scripts/python/module/test_nutclient.py"
     ) ; then
         log_info "[testcase_sandbox_python_with_upsmon_credentials] PASSED: PyNUT did not complain"
         PASSED="`expr $PASSED + 1`"
@@ -1581,7 +1612,8 @@ testcase_sandbox_python_with_upsmon_credentials() {
 }
 
 testcases_sandbox_python() {
-    isTestablePython || return 0
+    isTestablePython && [ -n "${PYTHON}" ] || return 0
+
     testcase_sandbox_python_without_credentials
     testcase_sandbox_python_with_credentials
     testcase_sandbox_python_with_upsmon_credentials
