@@ -1,9 +1,9 @@
 #!/usr/bin/env perl
-#   Current Version : 1.5
+#   Current Version : 1.6
 #   Copyright (C) 2008 - 2012 dloic (loic.dardant AT gmail DOT com)
 #   Copyright (C) 2008 - 2015 Arnaud Quette <arnaud.quette@free.fr>
 #   Copyright (C) 2013 - 2014 Charles Lepple <clepple+nut@gmail.com>
-#   Copyright (C) 2014 - 2024 Jim Klimov <jimklimov+nut@gmail.com>
+#   Copyright (C) 2014 - 2025 Jim Klimov <jimklimov+nut@gmail.com>
 #
 #   Based on the usbdevice.pl script, made for the Ubuntu Media Center
 #   for the final use of the LIRC project.
@@ -100,6 +100,7 @@ sub gen_usb_files
 	# Hotplug file header
 	my $outHotplug = do {local *OUT_HOTPLUG};
 	open $outHotplug, ">$outputHotplug" || die "error $outputHotplug : $!";
+	binmode $outHotplug;
 	print $outHotplug '# This file is generated and installed by the Network UPS Tools package.'."\n";
 	print $outHotplug "#\n";
 	print $outHotplug '# Sample entry (replace 0xVVVV and 0xPPPP with vendor ID and product ID respectively) :'."\n";
@@ -113,6 +114,7 @@ sub gen_usb_files
 	# Udev file header
 	my $outUdev = do {local *OUT_UDEV};
 	open $outUdev, ">$outputUdev" || die "error $outputUdev : $!";
+	binmode $outUdev;
 	print $outUdev '# This file is generated and installed by the Network UPS Tools package.'."\n\n";
 	print $outUdev 'ACTION=="remove", GOTO="nut-usbups_rules_end"'."\n";
 	print $outUdev 'SUBSYSTEM=="usb_device", GOTO="nut-usbups_rules_real"'."\n";
@@ -122,11 +124,13 @@ sub gen_usb_files
 
 	my $out_devd = do {local *OUT_DEVD};
 	open $out_devd, ">$output_devd" || die "error $output_devd : $!";
+	binmode $out_devd;
 	print $out_devd '# This file is generated and installed by the Network UPS Tools package.'."\n";
 	print $out_devd "# Homepage: https://www.networkupstools.org/\n\n";
 
 	my $out_freebsd_quirks = do {local *OUT_FREEBSD_QUIRKS};
 	open $out_freebsd_quirks, ">$output_freebsd_quirks" || die "error $output_freebsd_quirks : $!";
+	binmode $out_freebsd_quirks;
 	print $out_freebsd_quirks '# This file is generated and installed by the Network UPS Tools package.'."\n";
 	print $out_freebsd_quirks "# Homepage: https://www.networkupstools.org/\n";
 	print $out_freebsd_quirks "# Contents should be added to /boot/loader.conf.local (watch out for unique quirk numbers!)\n";
@@ -136,6 +140,7 @@ sub gen_usb_files
 	# UPower file header
 	my $outUPower = do {local *OUT_UPOWER};
 	open $outUPower, ">$outputUPower" || die "error $outputUPower : $!";
+	binmode $outUPower;
 	print $outUPower '##############################################################################################################'."\n";
 	print $outUPower '# Uninterruptible Power Supplies with USB HID interfaces'."\n#\n";
 	print $outUPower '# This file was automatically generated by NUT:'."\n";
@@ -147,6 +152,7 @@ sub gen_usb_files
 	# Device scanner header
 	my $outDevScanner = do {local *OUT_DEV_SCANNER};
 	open $outDevScanner, ">$outputDevScanner" || die "error $outputDevScanner : $!";
+	binmode $outDevScanner;
 	print $outDevScanner "/* nutscan-usb.h - header with USB identifiers known to NUT drivers\n";
 	print $outDevScanner " * This file was automatically generated during NUT build by 'tools/nut-usbinfo.pl'\n *";
 	print $outDevScanner $GPL_header."\n */\n\n";
@@ -304,7 +310,7 @@ sub find_usbdevs
 	# To skip libtool wrappers or binary builds of drivers without
 	# extension as well as temporary make files that appear and
 	# dissipate (especially during parallel builds), ONLY walk
-	# the *.c and *.h files (and subdirs):
+	# the *.c and *.h files (and subdirs eventually, maybe):
 	return $File::Find::prune = 1 if !($_ =~ /\.[ch]$/);
 
 	my $nameFile=$_;
